UserDataBlock

Enum UserDataBlock 

#[non_exhaustive]
pub enum UserDataBlock<'a> { ResetAtApplicationLevel { subcode: ApplicationResetSubcode, }, FixedDataStructure { identification_number: IdentificationNumber, access_number: u8, status: StatusField, device_type_and_unit: u16, counter1: Counter, counter2: Counter, }, VariableDataStructureWithLongTplHeader { extended_link_layer: Option<ExtendedLinkLayer>, long_tpl_header: LongTplHeader, variable_data_block: &'a [u8], }, VariableDataStructureWithShortTplHeader { extended_link_layer: Option<ExtendedLinkLayer>, short_tpl_header: ShortTplHeader, variable_data_block: &'a [u8], }, VariableDataStructureWithoutTplHeader { extended_link_layer: Option<ExtendedLinkLayer>, variable_data_block: &'a [u8], }, }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ResetAtApplicationLevel



FixedDataStructure

Fields

identification_number: IdentificationNumber
access_number: u8
device_type_and_unit: u16
counter1: Counter
counter2: Counter


VariableDataStructureWithLongTplHeader

Fields

extended_link_layer: Option<ExtendedLinkLayer>
long_tpl_header: LongTplHeader
variable_data_block: &'a [u8]


VariableDataStructureWithShortTplHeader

Fields

extended_link_layer: Option<ExtendedLinkLayer>
short_tpl_header: ShortTplHeader
variable_data_block: &'a [u8]


VariableDataStructureWithoutTplHeader

Fields

extended_link_layer: Option<ExtendedLinkLayer>
variable_data_block: &'a [u8]

Implementations

Source

impl<'a> UserDataBlock<'a>

pub fn data_records(&self) -> Option<DataRecords<'_>>

Returns an iterator over the variable data records in this block.

Fixed data structures, control messages, and encrypted payloads do not expose records. Decrypt an encrypted payload before parsing its records.

pub fn is_encrypted(&self) -> Option<bool>

pub fn variable_data_len(&self) -> usize

Returns the length of the variable data block (encrypted payload size)