pub const fn parse_data_records(data: &[u8]) -> DataRecords<'_> ⓘExpand description
Parses DIF/VIF data records after any CI and transport headers were removed.
The returned iterator yields one result per record and does not allocate.
pub const fn parse_data_records(data: &[u8]) -> DataRecords<'_> ⓘParses DIF/VIF data records after any CI and transport headers were removed.
The returned iterator yields one result per record and does not allocate.