ValueInformation

Struct ValueInformation 

pub struct ValueInformation<'a> {
    pub decimal_scale_exponent: isize,
    pub decimal_offset_exponent: isize,
    /* private fields */
}
A borrowed, allocation-free view of decoded VIF and VIFE information.

Labels and units are produced in wire order, including duplicates. The view borrows frame bytes, independently of the block used to construct it.

Fields

decimal_scale_exponent: isizedecimal_offset_exponent: isize

Implementations

Source

impl<'a> ValueInformation<'a>

pub fn labels(&self) -> ValueLabels<'a>

Iterates over all decoded labels in wire order.

pub fn units(&self) -> Units<'a>

Iterates over all decoded units in wire order.

pub fn has_label(&self, label: ValueLabel) -> bool

pub fn first_unit(&self) -> Option<Unit>