pub struct ValueInformation<'a> {
pub decimal_scale_exponent: isize,
pub decimal_offset_exponent: isize,
/* private fields */
}Expand description
A borrowed, allocation-free view of decoded VIF and VIFE information.
Labels and units are produced in wire order, including duplicates. The view borrows frame bytes, independently of the block used to construct it.
Fields
decimal_scale_exponent: isizedecimal_offset_exponent: isizeImplementations
Sourceimpl<'a> ValueInformation<'a>
impl<'a> ValueInformation<'a>